# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .run import Run

__all__ = ["RunListResponse"]

RunListResponse: TypeAlias = List[Run]
